import tkinter as Tkinter
from tkinter import ttk as ttk, scrolledtext, Menu
from tkinter.font import Font
import datetime


class Gui(Tkinter.Frame):
    def __init__(self, parent, api):
        self.parent = parent
        self.api = api
        Tkinter.Frame.__init__(self, parent)
        from tkcalendar import Calendar, DateEntry
        self.frame_font = Font(family="Helvetica", size=9)

        self.menu_bar = Menu(parent)
        parent.config(menu=self.menu_bar)

        self.file_menu = Menu(self.menu_bar)
        self.file_menu.add_command(label="Exit", command=self.terminate_window)
        self.menu_bar.add_cascade(label="File", menu=self.file_menu)

        self.tab_control = ttk.Notebook(self.parent)
        self.quotes_tab = ttk.Frame(self.tab_control)
        self.pattern_tab = ttk.Frame(self.tab_control)
        self.history_tab = ttk.Frame(self.tab_control)

        self.tab_control.add(self.quotes_tab, text="Quotes")
        self.tab_control.add(self.history_tab, text="History Lookup")
        self.tab_control.add(self.pattern_tab, text="Trading Patterns")


        self.tab_control.grid()

        # ## quotes_tab ## #

        # Set the label for the text box
        self.search_label = ttk.Label(self.quotes_tab, text="Look up stonk")
        self.search_label.grid(column=0, row=0, padx=5, sticky=Tkinter.W)

        # Create the text box
        self.symbol_search = Tkinter.Entry(self.quotes_tab, borderwidth=1, width=40)
        self.symbol_search.grid(column=0, row=1, padx=70, sticky=Tkinter.EW)
        self.symbol_search.configure(font=self.frame_font)

        # Create button to execute the search
        self.search_button = Tkinter.Button(self.quotes_tab, text="Search", command=self.search_button_action)
        self.search_button.grid(column=0, row=1, ipadx=2, ipady=1, padx=5, pady=1, sticky=Tkinter.W)

        # Set the label for the scrolled text
        self.scr_label = ttk.Label(self.quotes_tab, text="Actions")
        self.scr_label.grid(column=0, row=3, columnspan=1, padx=5, pady=(20, 5), sticky=Tkinter.SW)


        # Create the status box (scrollable)
        self.scr = scrolledtext.ScrolledText(self.quotes_tab, wrap=Tkinter.WORD, state="disabled",
                                             background="#3f3f3f", foreground="#2bc48f",
                                             width=100, height=20)
        self.scr.grid(column=0, row=4, sticky=Tkinter.NSEW)
        self.scr.configure(font=self.frame_font)

        # ## history_tab ## #
        # Set the label for the text box
        self.history_symbol_label = ttk.Label(self.history_tab, text="Ticket symbol")
        self.history_symbol_label.grid(column=0, row=0, padx=(5, 0), sticky=Tkinter.W)

        # Create the text box
        self.history_symbol_search = Tkinter.Entry(self.history_tab, borderwidth=1, width=40)
        self.history_symbol_search.grid(column=0, row=1, padx=(5, 0), sticky=Tkinter.EW)
        self.history_symbol_search.configure(font=self.frame_font)

        # Set the label for the text box
        self.history_start_label = ttk.Label(self.history_tab, text="Date start")
        self.history_start_label.grid(column=0, row=2, padx=5, sticky=Tkinter.W)

        # Create the text box
        self.history_start = Calendar(self.history_tab, selectmode="day")
        self.history_start.grid(column=0, row=3, padx=5, sticky=Tkinter.EW)
        self.history_start.configure(font=self.frame_font)

        # Set the label for the text box
        self.history_end_label = ttk.Label(self.history_tab, text="Date end")
        self.history_end_label.grid(column=1, row=2, padx=(5, 0), sticky=Tkinter.W)

        # Create the text box
        self.history_end = Calendar(self.history_tab, selectmode="day")
        self.history_end.grid(column=1, row=3, padx=(5, 0), sticky=Tkinter.EW)
        self.history_end.configure(font=self.frame_font)

        # Set the label for the multi-select area
        self.history_action_label = ttk.Label(self.history_tab, text="What are we tracking?")
        self.history_action_label.grid(column=0, row=6, sticky=Tkinter.W, pady=(10, 0))

        # Checkbox 1
        self.high_check = ttk.Checkbutton(self.history_tab, text="Record High")
        self.high_check.grid(column=0, row=8, padx=5, sticky=Tkinter.NW)
        self.low_check = ttk.Checkbutton(self.history_tab, text="Record Low")
        self.low_check.grid(column=0, row=9, padx=5, sticky=Tkinter.NW)
        self.average_check = ttk.Checkbutton(self.history_tab, text="Average Price")
        self.average_check.grid(column=0, row=10, padx=5, sticky=Tkinter.NW)
        self.average_close_check = ttk.Checkbutton(self.history_tab, text="Average Closing Price")
        self.average_close_check.grid(column=1, row=8, padx=(5, 0), sticky=Tkinter.NW)
        self.average_open_check = ttk.Checkbutton(self.history_tab, text="Average Opening Price")
        self.average_open_check.grid(column=1, row=9, padx=(5, 0), sticky=Tkinter.NW)
        self.average_volume_check = ttk.Checkbutton(self.history_tab, text="Average Volume")
        self.average_volume_check.grid(column=1, row=10, padx=(5, 0), sticky=Tkinter.NW)



    def terminate_window(self):
        self.parent.quit()
        self.parent.destroy()

    def search_button_action(self):
        raw_symbol = self.symbol_search.get()
        symbol = "{}".format(raw_symbol).upper()
        response = self.api.get_quote(symbol)
        print(response.__dict__["_raw"].keys())
        ask_price = response.__dict__["_raw"]["askprice"]
        ask_size = response.__dict__["_raw"]["asksize"]
        ask_ex = response.__dict__["_raw"]["askexchange"]
        bid_price = response.__dict__["_raw"]["bidprice"]
        bid_size = response.__dict__["_raw"]["bidsize"]
        bid_ex = response.__dict__["_raw"]["bidexchange"]
        # timestamp = datetime.datetime.fromtimestamp(response.__dict__["_raw"]["timestamp"])
        output_rows = [
            f"Retrieved quote for {symbol}", "\n",
            f"Ask:", f"Price: {ask_price}", f"Size: {ask_size}", f"Exchange: {ask_ex}", "\n"
            f"Bid:", f"Price: {bid_price}", f"Size: {bid_size}", f"Exchange: {bid_ex}"
        ]

        for row in output_rows:
            self.scr["state"] = "normal"
            self.scr.insert("end", f"{row}\n")
            self.scr["state"] = "disabled"




#


